==> herold_6.0.2.orig.tar.gz: src/java/org/dbdoclet/trafo/html/docbook/DbtConstants.java <==
package org.dbdoclet.trafo.html.docbook;

public class DbtConstants {

	public static final String DEFAULT_DESTINATION_ENCODING = "UTF-8";
	public static final String DEFAULT_EMPHASIS_ROLE_BOLD = "bold";
	public static final String DEFAULT_EMPHASIS_ROLE_ITALIC = "italic";
	public static final String DEFAULT_EMPHASIS_ROLE_UNDERLINE = "underline";
	public static final String DEFAULT_IMAGE_PATH = "img";
	public static final String DEFAULT_SOURCE_ENCODING = "UTF-8";
	public static final String DEFAULT_TABLE_STYLE = "all";
	public static final boolean DEFAULT_DECOMPOSE_TABLES = false;
	public static final int DEFAULT_MAX_LINE_WIDTH = 75;

	// public static final String DEFAULT_SECTION_NUMBERING_PATTERN =
	// "(((\\d\\.)+)?\\d*\\.?\\p{Z}*).*";

	public static final String SECTION_DOCBOOK = "DocBook";
	public static final String SECTION_HTML = "HTML";
	public static final String SECTION_IMPORT = "import";
	public static final String SECTION_MAIN = "main";

	public static final String PARAM_DOCBOOK_ADD_INDEX = "add-index";
	public static final String PARAM_DOCBOOK_CREATE_XREF_LABEL = "create-xref-label";
	public static final String PARAM_DOCBOOK_DECOMPOSE_TABLES = "decompose-tables";
	public static final String PARAM_DOCBOOK_DESTINATION_ENCODING = "encoding";
	public static final String PARAM_DOCBOOK_DOCUMENTATION_ID = "documentation-id";
	public static final String PARAM_DOCBOOK_DOCUMENT_ELEMENT = "document-element";
	public static final String PARAM_DOCBOOK_HYPHENATION_CHAR = "hyphenation-char";
	public static final String PARAM_DOCBOOK_IMAGEDATA_FORMATS = "image-data-formats";
	public static final String PARAM_DOCBOOK_IMAGE_PATH = "image-path";
	public static final String PARAM_DOCBOOK_LANGUAGE = "language";
	public static final String PARAM_DOCBOOK_TABLE_STYLE = "table-style";
	public static final String PARAM_DOCBOOK_TITLE = "title";
	public static final String PARAM_DOCBOOOK_TITLE_NORMALIZE_SPACE = "title-normalize-space";
	public static final String PARAM_DOCBOOK_USE_ABSOLUTE_IMAGE_PATH = "use-absolute-image-path";
	public static final String PARAM_DOCBOOK_VERSION = "docbook-version";
	public static final String PARAM_HTML_EXCLUDE = "exclude";
	public static final String PARAM_HTML_SECTION_NUMBERING_PATTERN = "section-numbering-pattern";
	public static final String PARAM_HTML_SOURCE_ENCODING = "encoding";
	public static final String PARAM_DOCBOOOK_COLLAPSE_PROTECTED_SPACE = "collapse-protected-space";
	public static final String PARAM_IMPORT_FILE = "file";
	public static final String PARAM_DOCBOOK_AUTHOR_FIRSTNAME = "author-firstname";
	public static final String PARAM_DOCBOOK_AUTHOR_EMAIL = "author-email";
	public static final String PARAM_DOCBOOK_AUTHOR_SURNAME = "author-surname";
	public static final String PARAM_DOCBOOK_COPYRIGHT_HOLDER = "copyright-holder";
	public static final String PARAM_DOCBOOK_COPYRIGHT_YEAR = "copyright-year";
	public static final String PARAM_DOCBOOK_CORPORATION = "corporation";
	public static final String PARAM_DOCBOOK_RELEASE_INFO = "release-info";
	public static final String PARAM_DOCBOOK_CREATE_PROLOG = "create-prolog";
	public static final String PARAM_DOCBOOK_ABSTRACT = "abstract";
}

==> herold_6.0.4.orig.tar.gz: src/java/org/dbdoclet/trafo/html/docbook/DbtConstants.java <==
package org.dbdoclet.trafo.html.docbook;

public class DbtConstants {

	public static final String DEFAULT_DESTINATION_ENCODING = "UTF-8";
	public static final String DEFAULT_EMPHASIS_ROLE_BOLD = "bold";
	public static final String DEFAULT_EMPHASIS_ROLE_ITALIC = "italic";
	public static final String DEFAULT_EMPHASIS_ROLE_UNDERLINE = "underline";
	public static final String DEFAULT_IMAGE_PATH = "img";
	public static final String DEFAULT_SOURCE_ENCODING = "UTF-8";
	public static final String DEFAULT_TABLE_STYLE = "all";
	public static final boolean DEFAULT_DECOMPOSE_TABLES = false;
	public static final int DEFAULT_MAX_LINE_WIDTH = 75;

	// public static final String DEFAULT_SECTION_NUMBERING_PATTERN =
	// "(((\\d\\.)+)?\\d*\\.?\\p{Z}*).*";

	public static final String SECTION_DOCBOOK = "DocBook";
	public static final String SECTION_HTML = "HTML";
	public static final String SECTION_IMPORT = "import";
	public static final String SECTION_INPUT = "input";
	public static final String SECTION_MAIN = "main";
	public static final String SECTION_OUTPUT = "output";

	public static final String PARAM_DOCBOOK_ABSTRACT = "abstract";
	public static final String PARAM_DOCBOOK_ADD_INDEX = "add-index";
	public static final String PARAM_DOCBOOK_AUTHOR_EMAIL = "author-email";
	public static final String PARAM_DOCBOOK_AUTHOR_FIRSTNAME = "author-firstname";
	public static final String PARAM_DOCBOOK_AUTHOR_SURNAME = "author-surname";
	public static final String PARAM_DOCBOOK_COLLAPSE_PROTECTED_SPACE = "collapse-protected-space";
	public static final String PARAM_DOCBOOK_COPYRIGHT_HOLDER = "copyright-holder";
	public static final String PARAM_DOCBOOK_COPYRIGHT_YEAR = "copyright-year";
	public static final String PARAM_DOCBOOK_CORPORATION = "corporation";
	public static final String PARAM_DOCBOOK_CREATE_CONDITION_ATTRIBUTE = "create-condition-attribute";
	public static final String PARAM_DOCBOOK_CREATE_PROLOG = "create-prolog";
	public static final String PARAM_DOCBOOK_CREATE_REMAP_ATTRIBUTE = "create-remap-attribute";
	public static final String PARAM_DOCBOOK_CREATE_XREF_LABEL = "create-xref-label";
	public static final String PARAM_DOCBOOK_DECOMPOSE_TABLES = "decompose-tables";
	public static final String PARAM_DOCBOOK_DETECT_TRAPPED_BR = "detect-trapped-br";
	public static final String PARAM_DOCBOOK_DOCUMENTATION_ID = "documentation-id";
	public static final String PARAM_DOCBOOK_DOCUMENT_ELEMENT = "document-element";
	public static final String PARAM_DOCBOOK_ENCODING = "encoding";
	public static final String PARAM_DOCBOOK_HYPHENATION_CHAR = "hyphenation-char";
	public static final String PARAM_DOCBOOK_IMAGEDATA_FORMATS = "image-data-formats";
	public static final String PARAM_DOCBOOK_IMAGE_PATH = "image-path";
	public static final String PARAM_DOCBOOK_LANGUAGE = "language";
	public static final String PARAM_DOCBOOK_RELEASE_INFO = "release-info";
	public static final String PARAM_DOCBOOK_TABLE_STYLE = "table-style";
	public static final String PARAM_DOCBOOK_TITLE = "title";
	public static final String PARAM_DOCBOOK_TITLE_NORMALIZE_SPACE = "title-normalize-space";
	public static final String PARAM_DOCBOOK_USE_ABSOLUTE_IMAGE_PATH = "use-absolute-image-path";
	public static final String PARAM_DOCBOOK_VERSION = "docbook-version";
	public static final String PARAM_HTML_EXCLUDE = "exclude";
	public static final String PARAM_HTML_SECTION_NUMBERING_PATTERN = "section-numbering-pattern";
	public static final String PARAM_HTML_SOURCE_ENCODING = "encoding";
	public static final String PARAM_FILE = "file";
}
